<?php

/**
 * @package: editorify-plugin
 */

/**
 * Plugin Name: Editorify
 * Description: Boost Your Sales By Adding Products Reviews, Videos & Images to your product page
 * Version: 1.0.0
 * Author: Editorify
 * Author URI: https://editorify.com
 * License: GPLv3 or later
 * Text Domain: editorify-plugin
 */

if (!defined('ABSPATH')) {
    die;
}

define("EDITORIFY_API_URL", "https://apps.editorify.com");
define('EDITORIFY_VERSION', '1.0');
define('EDITORIFY_PATH', dirname(__FILE__));
define('EDITORIFY_FOLDER', basename(EDITORIFY_PATH));
define('EDITORIFY_URL', plugins_url() . '/' . EDITORIFY_FOLDER);
define('EDITORIFY_API_KEY', get_option('editorify_api_key'));
define("EDITORIFY_DEVELOPMENT", (stripos(EDITORIFY_API_URL, "dev.editorify") !== false ? "dev" : ""));
define("EDITORIFY_DEBUG", true);

register_activation_hook(__FILE__, 'editorify_activation_hook');
register_deactivation_hook(__FILE__, 'editorify_deactivation_hook');
register_uninstall_hook(__FILE__, 'editorify_uninstall_hook');
add_action('admin_enqueue_scripts', 'editorify_add_admin_css_js');
add_action('admin_menu', 'editorify_admin_menu');
add_action('wp_head', 'editorify_script');
add_action("wp_ajax_nopriv_editorify_installation", "editorify_installation");
add_action("wp_ajax_editorify_installation", "editorify_installation");

function editorify_activation_hook()
{
    $data = array(
        'store' => get_site_url(),
        'email' => get_option('admin_email'),
        'event' => 'install'
    );

    $response = editorify_send_request('/auth/woocomerce-activate', $data);

    if ($response) {
        if ($response['success'] > 0) {

            editorify_log('api key: ' . $response['api_key'], get_site_url());
            editorify_log((!get_option('editorify_api_key') ? "yes" : "no"), get_site_url());

            if (!get_option('editorify_api_key')) {
                add_option('editorify_api_key', $response['api_key']);

                editorify_log($response['app_name'] . " " . $response['user_id'] . " " . $response['scope'], get_site_url());

                if (class_exists("WC_Auth")) {
                    class Editorify_AuthCustom extends WC_Auth
                    {
                        public function getKeys($app_name, $user_id, $scope)
                        {
                            return parent::create_keys($app_name, $user_id, $scope);
                        }
                    }

                    $auth = new Editorify_AuthCustom();
                    $keys = $auth->getKeys($response['app_name'], $response['user_id'], $response['scope']);
                    $data = array(
                        'store' => get_site_url(),
                        'keys' => $keys,
                        'user_id' => $response['user_id'],
                        'event' => 'update_keys'
                    );

                    $keys_response = editorify_send_request('/auth/woocomerce-activate', $data);

                    if ($keys_response && $keys_response['success'] == 0) {
                        add_option('editorify_error', 'yes');
                        add_option('editorify_error_message', $keys_response['message']);
                    }
                }

                editorify_log('after auth');
            } else {
                update_option('editorify_api_key', $response['api_key']);
            }
        } else {
            editorify_log('invalid response - api key', get_site_url());

            if (!get_option('editorify_error')) {
                add_option('editorify_error', 'yes');
                add_option('editorify_error_message', 'Error activation plugin!');
            }
        }
    } else {
        editorify_log('error getting response - api key', get_site_url());

        if (!get_option('editorify_error')) {
            add_option('editorify_error', 'yes');
            add_option('editorify_error_message', 'Error activation plugin!');
        }
    }
}

function editorify_deactivation_hook()
{
    if (!current_user_can('activate_plugins')) {
        return;
    }
    $data = array(
        'store' => get_site_url(),
        'event' => 'deactivated',
    );
    return editorify_send_request('/auth/woocomerce-deactivate', $data);
}

function editorify_uninstall_hook()
{
    if (!current_user_can('activate_plugins')) {
        return;
    }

    delete_option('editorify_api_key');

    if (get_option('editorify_error')) {
        delete_option('editorify_error');
    }

    if (get_option('editorify_error_message')) {
        delete_option('editorify_error_message');
    }

    editorify_clear_all_caches();

    $data = array(
        'store' => get_site_url(),
        'event' => 'uninstall',
    );
    return editorify_send_request('/auth/woocomerce-deactivate', $data);
}

function editorify_script()
{
    if (strlen(EDITORIFY_API_KEY) > 0) {
        $attributes = array(
            'id' => EDITORIFY_DEVELOPMENT . 'editorifyScript',
            'async' => true,
            'src' => esc_url("https://www.editorify.net/js/woo_reviews.js?key=" . EDITORIFY_API_KEY),
        );
        wp_print_script_tag($attributes);
    }
}

function editorify_add_admin_css_js()
{
    wp_register_style('editorify_style', EDITORIFY_URL . '/assets/css/style.css');
    wp_enqueue_style('editorify_style');
    wp_register_script('editorify-admin', EDITORIFY_URL . '/assets/js/script.js', array('jquery'), '1.0.0');
    wp_enqueue_script('editorify-admin');
}

function editorify_admin_menu()
{
    add_menu_page('Editorify Settings', 'Editorify', 'manage_options', 'Editorify', 'editorify_admin_menu_page_html', EDITORIFY_URL . '/assets/images/editorify_icon.png');
}

function editorify_has_woocommerce()
{
    return in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins')));
}

function editorify_admin_menu_page_html()
{
    include_once EDITORIFY_PATH . '/views/editorify_admin_page.php';
}

function editorify_send_request($path, $data)
{
    try {
        $headers = array(
            'Content-Type' => 'application/json',
            'x-plugin-version' => EDITORIFY_VERSION,
            'x-site-url' => get_site_url(),
            'x-wp-version' => get_bloginfo('version'),
        );

        if (editorify_has_woocommerce()) {
            $headers['x-woo-version'] = WC()->version;
        }

        $url = EDITORIFY_API_URL . $path;
        $data = array(
            'headers' => $headers,
            'body' => json_encode($data),
        );
        editorify_log('sending request', $url);
        $response = wp_remote_post($url, $data);
        editorify_log('got response', $url);

        if (!is_wp_error($response)) {

            $decoded_response = json_decode(wp_remote_retrieve_body($response), true);

            return $decoded_response;
        }
        return 0;
    } catch (Exception $err) {
        editorify_handle_error('failed sending request', $err, $data);
    }
}

function editorify_log($message, $data = null)
{
    $log = null;

    if (isset($data)) {
        $log = "\n[Editorify] " . $message . ":\n" . print_r($data, true);
    } else {
        $log = "\n[Editorify] " . $message;
    }
    error_log($log);

    if (EDITORIFY_DEBUG) {
        $plugin_log_file = plugin_dir_path(__FILE__) . 'debug.log';
        error_log($log . "\n", 3, $plugin_log_file);
    }
}

function editorify_handle_error($message, $err, $data = null)
{
    editorify_log($message, $err);
}

function editorify_plugin_redirect()
{
    exit(wp_redirect("admin.php?page=Editorify"));
}

function editorify_clear_all_caches()
{
    try {
        global $wp_fastest_cache;

        if (function_exists('w3tc_flush_all')) {
            w3tc_flush_all();
        }

        if (function_exists('wp_cache_clean_cache')) {
            global $file_prefix, $supercachedir;
            if (empty($supercachedir) && function_exists('get_supercache_dir')) {
                $supercachedir = get_supercache_dir();
            }
            wp_cache_clean_cache($file_prefix);
        }
        if (method_exists('WpFastestCache', 'deleteCache') && !empty($wp_fastest_cache)) {
            $wp_fastest_cache->deleteCache();
        }

        if (function_exists('rocket_clean_domain')) {
            rocket_clean_domain();
            // Preload cache.
            if (function_exists('run_rocket_sitemap_preload')) {
                run_rocket_sitemap_preload();
            }
        }
        if (class_exists("autoptimizeCache") && method_exists("autoptimizeCache", "clearall")) {
            autoptimizeCache::clearall();
        }
        if (class_exists("LiteSpeed_Cache_API") && method_exists("autoptimizeCache", "purge_all")) {
            LiteSpeed_Cache_API::purge_all();
        }

        if (class_exists('\Hummingbird\Core\Utils')) {
            $modules = \Hummingbird\Core\Utils::get_active_cache_modules();
            foreach ($modules as $module => $name) {
                $mod = \Hummingbird\Core\Utils::get_module($module);

                if ($mod->is_active()) {
                    if ('minify' === $module) {
                        $mod->clear_files();
                    } else {
                        $mod->clear_cache();
                    }
                }
            }
        }
    } catch (Exception $e) {
        return 1;
    }
}
function editorify_installation()
{
    if (in_array('woocommerce/woocommerce.php', apply_filters('active_plugins', get_option('active_plugins'))) && !get_option('editorify_error')) {
        $json['success'] = 1;
        $json['api_key'] = get_option('editorify_api_key');
    } else {
        $json["success"] = 0;
    }

    wp_send_json($json);
    wp_die();
}

?>